#include "snake.h"


/* external functions */
extern void finish (void);
extern void show_scores (void);


/* private data */
int menulines;
int menucols;
int menu_y_offset;
int menu_x_offset;

/* public data */
WINDOW *menuwin;
snake **zoo;

/* public functions */
void show_menu (void);
void make_menu (void);

/* private functions */
static void line_up (void);
static void line_down (void);
static void highlight (int);
static void downlight (int);

/* private data */
static int cursor = 0;
static int menuoffset = 5;
static int menulength = 3;
static struct menuitem_t {
	char label[256];
	void (*function)(void);
} menuitem [3] = {
	{ "show scores", &show_scores },
	{ "continue", NULL },
	{ "quit", &finish },
};

void show_menu ()
{
	int ch;
	void (*fp) (void);

	touchwin(menuwin);
	wrefresh(menuwin);

	while ( (ch=getch()) )
	{
		switch (ch)
		{
			case 'j':
				line_down();
				continue;

			case 'k':
				line_up();
				continue;
				
			/* ENTER */
			case 10:
				fp = menuitem[cursor].function;
				if ( fp ) fp();
				else break;
				continue;

			/* ESC */
			case 27:
				break;

			default:
				continue;
		}	
		break;
	}

	touchwin(arenawin);
	wrefresh(arenawin);
}

void make_menu ()
{
	int i;

	menulines = LINES - (LINES/4);
	menucols = COLS - (COLS/4);
	menu_y_offset = (LINES - menulines) / 2;
	menu_x_offset = (COLS - menucols) / 2;
	menuwin = newwin (menulines, menucols,
	                  menu_y_offset, menu_x_offset);

	wborder(menuwin, '|', '|', '-', '-', '*', '*', '*', '*');

	mvwaddstr(menuwin, 0, (menucols/2)-4, "* MENU *");

	for ( i=0; i<menulength; i++ )
	{
		mvwaddstr(menuwin, menuoffset+i, 10, menuitem[i].label);
	}

	highlight(cursor);
}

static void line_down ()
{
	downlight(cursor);
	cursor++;
	if ( cursor >= menulength ) cursor = 0;
	highlight(cursor);
	touchwin(menuwin);
	wrefresh(menuwin);
}

static void line_up ()
{
	downlight(cursor);
	cursor--;
	if ( cursor < 0 ) cursor = menulength-1;
	highlight(cursor);
	touchwin(menuwin);
	wrefresh(menuwin);
}

static void highlight (int line)
{
	mvwchgat(menuwin, line+menuoffset, 2, menucols-4,
	         A_REVERSE, 0, NULL);
}

static void downlight (int line)
{
	mvwchgat(menuwin, line+menuoffset, 2, menucols-4,
	         A_NORMAL, 0, NULL);
}
